@@ -1,3 +1,8 @@
+try:
+    import cPickle as pickle
+except ImportError:
+    import pickle
+
 import pytest
 
 import requests
@@ -167,7 +172,11 @@ class TestGitHubSession:
         s = self.build_session()
         assert s.two_factor_auth_cb is None
         # You have to have a sense of humor ;)
-        not_so_anonymous = lambda *args: 'foo'
+
+        def _not_so_anonymous(*args):
+            return 'foo'
+
+        not_so_anonymous = _not_so_anonymous
         s.two_factor_auth_callback(not_so_anonymous)
         assert s.two_factor_auth_cb is not_so_anonymous
 
@@ -231,3 +240,14 @@ class TestGitHubSession:
         """
         s = self.build_session()
         assert s.retrieve_client_credentials() == (None, None)
+
+    def test_pickling(self):
+        s = self.build_session('https://api.github.com')
+        dumped = pickle.dumps(s, pickle.HIGHEST_PROTOCOL)
+        loaded = pickle.loads(dumped)
+
+        assert hasattr(loaded, 'base_url')
+        assert hasattr(loaded, 'two_factor_auth_cb')
+
+        assert loaded.base_url == s.base_url
+        assert loaded.two_factor_auth_cb == s.two_factor_auth_cb
